@@ -39,7 +39,7 @@ use vars qw[@ISA $VERSION];
             CPANPLUS::Internals::Report
         ];
 
-$VERSION = "0.9170";
+$VERSION = "0.9174";
 
 =pod
 
@@ -268,7 +268,7 @@ be flushed.
             } elsif ( $what eq 'methods' ) {
 
                 ### still unbelievably p4 :( ###
-                $File'Fetch::METHOD_FAIL = $File'Fetch::METHOD_FAIL = {};
+                $File::Fetch::METHOD_FAIL = $File::Fetch::METHOD_FAIL = {};
 
             ### blow away the m::l::c cache, so modules can be (re)loaded
             ### again if they become available
